@@ -14,6 +14,7 @@
 
 #include "actor.h"
 #include "alpha.h"
+#include "animation.h"
 #include "behaviour.h"
 #include "behaviour-depth.h"
 #include "behaviour-ellipse.h"
@@ -21,11 +22,13 @@
 #include "behaviour-path.h"
 #include "behaviour-rotate.h"
 #include "behaviour-scale.h"
+#include "cairo-texture.h"
 #include "childmeta.h"
 #include "clone.h"
 #include "color.h"
 #include "container.h"
 #include "group.h"
+#include "interval.h"
 #include "media.h"
 #include "path.h"
 #include "rectangle.h"
@@ -46,6 +49,7 @@ extern "C"
 
 GType clutter_actor_get_type(void);
 GType clutter_alpha_get_type(void);
+GType clutter_animation_get_type(void);
 GType clutter_behaviour_get_type(void);
 GType clutter_behaviour_depth_get_type(void);
 GType clutter_behaviour_ellipse_get_type(void);
@@ -56,6 +60,7 @@ GType clutter_behaviour_scale_get_type(void);
 GType clutter_child_meta_get_type(void);
 GType clutter_clone_get_type(void);
 GType clutter_group_get_type(void);
+GType clutter_interval_get_type(void);
 GType clutter_path_get_type(void);
 GType clutter_rectangle_get_type(void);
 GType clutter_score_get_type(void);
@@ -77,6 +82,7 @@ GQuark clutter_texture_error_quark(void);
 
 namespace Clutter {  class Actor_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Clutter {  class Alpha_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Clutter {  class Animation_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Clutter {  class Behaviour_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Clutter {  class BehaviourDepth_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Clutter {  class BehaviourEllipse_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -87,6 +93,7 @@ namespace Clutter {  class BehaviourScale_Class { public: static Glib::ObjectBas
 namespace Clutter {  class ChildMeta_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Clutter {  class Clone_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Clutter {  class Group_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Clutter {  class Interval_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Clutter {  class Path_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Clutter {  class Rectangle_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Clutter {  class Score_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -108,6 +115,7 @@ void wrap_init()
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(clutter_actor_get_type(), &Clutter::Actor_Class::wrap_new);
   Glib::wrap_register(clutter_alpha_get_type(), &Clutter::Alpha_Class::wrap_new);
+  Glib::wrap_register(clutter_animation_get_type(), &Clutter::Animation_Class::wrap_new);
   Glib::wrap_register(clutter_behaviour_get_type(), &Clutter::Behaviour_Class::wrap_new);
   Glib::wrap_register(clutter_behaviour_depth_get_type(), &Clutter::BehaviourDepth_Class::wrap_new);
   Glib::wrap_register(clutter_behaviour_ellipse_get_type(), &Clutter::BehaviourEllipse_Class::wrap_new);
@@ -118,6 +126,7 @@ void wrap_init()
   Glib::wrap_register(clutter_child_meta_get_type(), &Clutter::ChildMeta_Class::wrap_new);
   Glib::wrap_register(clutter_clone_get_type(), &Clutter::Clone_Class::wrap_new);
   Glib::wrap_register(clutter_group_get_type(), &Clutter::Group_Class::wrap_new);
+  Glib::wrap_register(clutter_interval_get_type(), &Clutter::Interval_Class::wrap_new);
   Glib::wrap_register(clutter_path_get_type(), &Clutter::Path_Class::wrap_new);
   Glib::wrap_register(clutter_rectangle_get_type(), &Clutter::Rectangle_Class::wrap_new);
   Glib::wrap_register(clutter_score_get_type(), &Clutter::Score_Class::wrap_new);
@@ -131,6 +140,7 @@ void wrap_init()
   // Register the gtkmm gtypes:
   Clutter::Actor::get_type();
   Clutter::Alpha::get_type();
+  Clutter::Animation::get_type();
   Clutter::Behaviour::get_type();
   Clutter::BehaviourDepth::get_type();
   Clutter::BehaviourEllipse::get_type();
@@ -141,6 +151,7 @@ void wrap_init()
   Clutter::ChildMeta::get_type();
   Clutter::Clone::get_type();
   Clutter::Group::get_type();
+  Clutter::Interval::get_type();
   Clutter::Path::get_type();
   Clutter::Rectangle::get_type();
   Clutter::Score::get_type();
